@@ -155,17 +155,17 @@ class Create_maya(Create, Slots_maya):
 	def createCircle(self, axis='y', numPoints=5, radius=5, center=[0,0,0], mode=0, name='pCircle'):
 		'''Create a circular polygon plane.
 
-		:Parameters:
+		Parameters:
 			axis (str): 'x','y','z' 
 			numPoints(int): number of outer points
 			radius=int
 			center=[float3 list] - point location of circle center
 			mode(int): 0 -no subdivisions, 1 -subdivide tris, 2 -subdivide quads
 
-		:Return:
+		Return:
 			(list) [transform node, history node] ex. [nt.Transform('polySurface1'), nt.PolyCreateFace('polyCreateFace1')]
 
-		:Example: self.createCircle(axis='x', numPoints=20, radius=8, mode='tri')
+		Example: self.createCircle(axis='x', numPoints=20, radius=8, mode='tri')
 		'''
 		import math
 
@@ -238,7 +238,7 @@ print (__name__)
 	# 	'''undo previous rotation and rotate on the specified axis.
 	# 	uses an external rotation dictionary.
 
-	# 	:Parameters:
+	# 	Parameters:
 	# 		axis (str): axis to rotate on. ie. '-x'
 	# 		node (obj): transform node.
 	# 	'''
