@@ -195,7 +195,7 @@ class Rigging_maya(Rigging, Slots_maya):
 		'''
 		node = pm.ls(sl=1, objectsOnly=1)
 		if not node:
-			self.messageBox('Operation requires a single selected object.')
+			self.sb.messageBox('Operation requires a single selected object.')
 			return
 
 		params = ['enableTranslationX','translationX','enableTranslationY','translationY','enableTranslationZ','translationZ',
@@ -281,7 +281,7 @@ print (__name__)
 # 	'''Create locators with the same transforms as any selected object(s).
 # 	If there are vertices selected it will create a locator at the center of the selected vertices bounding box.
 
-# 	:Parameters:
+# 	Parameters:
 # 		suffix (str): A string appended to the end of the created locators name. (default: '_LOC') '_LOC#'
 # 		stripDigits (bool): Strip numeric characters from the string. If the resulting name is not unique, maya will append a trailing digit. (default=False)
 # 		strip (str): Strip a specific character set from the locator name. The locators name is based off of the selected objects name. (default=None)
@@ -294,7 +294,7 @@ print (__name__)
 # 		lockScale (bool): Lock the scale values of the child object. (default=False)
 # 		_fullPath (bool): Internal use only (recursion). Use full path names for Dag objects. This can prevent naming conflicts when creating the locator. (default=False)
 
-# 	:Example:
+# 	Example:
 # 		createLocatorAtSelection(strip='_GEO', suffix='', stripDigits=True, scale=10, parent=True, lockTranslate=True, lockRotation=True)
 # 	'''
 # 	import pymel.core as pm
