@@ -8,7 +8,6 @@ from pythontk.Iter import makeList
 from uitk.switchboard import Switchboard
 from uitk.overlay import Overlay
 from uitk.events import EventFactoryFilter, MouseTracking
-from uitk.widgets import rwidgets
 
 
 class Tcl(QtWidgets.QStackedWidget):
@@ -19,33 +18,34 @@ class Tcl(QtWidgets.QStackedWidget):
 
 	The various ui's are set by calling 'setUi' with the intended ui name string. ex. Tcl().setUi('polygons')
 	'''
-	_mousePressPos = QtCore.QPoint()
-	_key_show_release = QtCore.Signal()
-
 	app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(sys.argv) #return the existing QApplication object, or create a new one if none exists.
 
+	_key_show_release = QtCore.Signal()
+
 	def __init__(self, parent=None, key_show='Key_F12', preventHide=False, slotLoc=''):
 		'''
-		:Parameters:
+		Parameters:
 			parent (obj): The parent application's top level window instance. ie. the Maya main window.
 		'''
 		super().__init__(parent)
 
-		self.sb = Switchboard(self, uiLoc='ui', widgetLoc=rwidgets, slotLoc=slotLoc, preloadUi=True)
-
 		self.key_show = getattr(QtCore.Qt, key_show)
 		self.key_undo = QtCore.Qt.Key_Z
 		self.key_close = QtCore.Qt.Key_Escape
 		self.preventHide = preventHide
+		self._mousePressPos = QtCore.QPoint()
 
 		# self.app.setDoubleClickInterval(400)
 		# self.app.setKeyboardInputInterval(400)
-		# self.app.focusChanged.connect(self.focusChanged)
+		self.setFocusPolicy(QtCore.Qt.StrongFocus)
 
 		self.setWindowFlags(QtCore.Qt.Tool|QtCore.Qt.FramelessWindowHint) #|QtCore.Qt.WindowStaysOnTopHint
 		self.setAttribute(QtCore.Qt.WA_TranslucentBackground)
-		self.setAttribute(QtCore.Qt.WA_SetStyle) #Indicates that the widget has a style of its own.
+		# self.setAttribute(QtCore.Qt.WA_SetStyle) #Indicates that the widget has a style of its own.
+		self.setAttribute(QtCore.Qt.WA_NoMousePropagation, False)
+		self.resize(1200, 1200)
 
+		self.sb = Switchboard(self, uiLoc='ui', widgetLoc='widgets', slotLoc=slotLoc, preloadUi=False)
 		self.overlay = Overlay(self, antialiasing=True) #Paint events are handled by the overlay module.
 		self.eventFilter = EventFactoryFilter(self, eventNamePrefix='ef_', forwardEventsTo=self)
 		self.mouseTracking = MouseTracking(self)
@@ -54,10 +54,10 @@ class Tcl(QtWidgets.QStackedWidget):
 	def initUi(self, ui):
 		'''Initialize the given ui.
 
-		:Parameters:
+		Parameters:
 			ui (obj): The ui to initialize.
 		'''
-		self.initWidgets(ui)
+		self.initWidgets(ui.widgets)
 
 		if ui.level<3: #stacked ui.
 			ui.setParent(self)
@@ -70,44 +70,38 @@ class Tcl(QtWidgets.QStackedWidget):
 
 			self._key_show_release.connect(ui.hide)
 
-		ui.isInitialized = True
-
 
 	def setUi(self, ui):
 		'''Set the stacked Widget's index to the given ui.
 
-		:Parameters:
+		Parameters:
 			ui (str)(obj): The ui or name of the ui to set the stacked widget index to.
 		'''
 		assert isinstance(ui, (str, QtWidgets.QWidget)), f'# Error: {__file__} in setUi\n#\tIncorrect datatype: {type(ui).__name__}'
 
 		ui = self.sb.getUi(ui) #Get the ui of the given name, and set it as the current ui in the switchboard module.
-		ui.connected = True
-
+		ui.setAsCurrent()
 		if not ui.isInitialized:
 			self.initUi(ui)
 
 		if ui.level<3: #stacked ui top level window.
 			self.setCurrentWidget(ui) #set the stacked widget to the given ui.
-			self.resize(ui.sizeX, ui.sizeY) #The ui sizes for individual ui's are stored in sizeX and sizeY properties. Otherwise size would be constrained to the largest widget in the stack)
 
 		else: #popup ui.
-			ui.show()
-			ui.resize(ui.minimumSizeHint()) #ui.adjustSize()
-			self.sb.moveAndCenterWidget(ui, QtGui.QCursor.pos(), offsetY=4) #move to cursor position and offset slightly.
-			ui.activateWindow() #activate the popup ui before hiding the stacked layout.
-			self.hide()
+			ui.resize(ui.minimumSizeHint())
+			self.sb.moveAndCenterWidget(ui, QtGui.QCursor.pos(), offsetY=4) #move to cursor position.
+			ui.show(); self.hide() #activate the popup ui before hiding the stacked layout.
 
 
 	def setSubUi(self, ui, w):
 		'''Set the stacked widget's index to the submenu associated with the given widget.
 		Positions the new ui to line up with the previous ui's button that called the new ui.
 
-		:Parameters:
+		Parameters:
 			ui (obj): The submenu ui to set as current.
 			w (obj): The widget that called this method.
 		'''
-		if not ui or ui==self.sb.currentUi:
+		if not ui or ui==self.sb.ui:
 			return
 
 		self.overlay.addToDrawPath(w)
@@ -118,6 +112,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		w2 = getattr(self.currentWidget(), w.name) #get the widget of the same name in the new ui.
 		p2 = w2.mapToGlobal(w2.rect().center()) #widget position after submenu change.
 		currentPos = self.mapToGlobal(self.pos())
+
 		self.move(self.mapFromGlobal(currentPos +(p1 - p2))) #currentPos + difference
 
 		if ui not in self.sb.getPrevUi(asList=True): #if the submenu ui called for the first time:
@@ -131,11 +126,11 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''Return the stacked widget to it's starting index.
 		'''
 		prevUi = self.sb.getPrevUi(omitLevel=2)
+		self.setWindowOpacity(0.01)
 		self.setUi(prevUi) #return the stacked widget to it's previous ui.
-
 		self.move(self.overlay.drawPathStartPos - self.rect().center())
-
 		self.overlay.clearDrawPath()
+		self.setWindowOpacity(255)
 
 
 	def cloneWidgetsAlongPath(self, ui):
@@ -143,15 +138,14 @@ class Tcl(QtWidgets.QStackedWidget):
 		Initializes the new buttons by adding them to the switchboard.
 		The previous widget information is derived from the widget and draw paths.
 
-		:Parameters:
+		Parameters:
 			ui (obj): The ui in which to copy the widgets to.
 		'''
-		for prevWgt, prevPos, drawPos in self.overlay.drawPath:
-			state = True if prevWgt.objectName()!='return_area' else False
-			w = self.sb.PushButton(ui, copy_=prevWgt, setPosition_=prevPos, setVisible=state)
-			self.initWidgets(ui, w) #initialize the widget to set things like the event filter and styleSheet.
-			self.sb.connectSlots(ui, w)
-
+		cloned_widgets = set(
+			self.sb.PushButton(ui, copy_=prevWgt, setPosition_=prevPos, setVisible=prevWgt.objectName()!='return_area')
+			for prevWgt, prevPos, drawPos in self.overlay.drawPath
+		)
+		ui.defer(self.initWidgets, cloned_widgets) #initialize the widget to set things like the event filter.
 
 
 	# ---------------------------------------------------------------------------------------------
@@ -203,7 +197,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''
 		modifiers = self.app.keyboardModifiers()
 
-		if self.sb.currentUi.level<3:
+		if self.sb.ui.level<3:
 			self.move(self.sb.getCenter(self))
 
 			if not modifiers:
@@ -224,7 +218,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		a mouse button is pressed while the mouse is being moved. If mouse tracking 
 		is switched on, mouse move events occur even if no mouse button is pressed.
 		'''
-		self.mouseTracking.track(self.sb.currentUi.widgets)
+		self.mouseTracking.track(self.sb.ui.widgets)
 
 		super().mouseMoveEvent(event)
 
@@ -245,7 +239,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''
 		modifiers = self.app.keyboardModifiers()
 
-		if self.sb.currentUi.level<3:
+		if self.sb.ui.level<3:
 			if event.button()==QtCore.Qt.LeftButton:
 
 				if modifiers in (QtCore.Qt.ControlModifier, QtCore.Qt.ControlModifier | QtCore.Qt.AltModifier):
@@ -262,26 +256,10 @@ class Tcl(QtWidgets.QStackedWidget):
 		super().mouseDoubleClickEvent(event)
 
 
-	def focusChanged(self, old, new):
-		'''Called on focus events.
-
-		:Parameters:
-			old (obj): The widget with previous focus.
-			new (obj): The widget with current focus.
-		'''
-		try:
-			new.grabKeyboard()
-		except AttributeError as error:
-			self.setFocus()
-
-		if not self.isActiveWindow():
-			self.hide()
-
-
 	def show(self, ui='init', profile=False):
 		'''Sets the widget as visible.
 
-		:Parameters:
+		Parameters:
 			ui (str)(obj): Show the given ui.
 			profile (bool): Prints the total running time, times each function separately, 
 				and tells you how many times each function was called.
@@ -294,24 +272,18 @@ class Tcl(QtWidgets.QStackedWidget):
 		else:
 			self.setUi(ui)
 
-		# self.activateWindow()
-		super().show()
-
-
-	def showEvent(self, event):
-		'''Non-spontaneous show events are sent to widgets immediately before they are shown.
-		'''
-		if self.sb.currentUi.level==0:
+		if self.sb.ui.level==0:
 			self.move(self.sb.getCenter(self))
 
-		super().showEvent(event)
+		super().show()
+		self.activateWindow() #the window cannot be activated for keyboard events until after it is shown.
 
 
 	def hide(self, force=False):
 		'''Sets the widget as invisible.
 		Prevents hide event under certain circumstances.
 
-		:Parameters:
+		Parameters:
 			force (bool): override preventHide.
 		'''
 		if force or not self.preventHide:
@@ -352,38 +324,24 @@ class Tcl(QtWidgets.QStackedWidget):
 		'QProgressBar',
 		'QMenu',
 	]
-	def initWidgets(self, ui, widgets=None):
+	def initWidgets(self, widgets):
 		'''Set Initial widget states.
 
-		:Parameters:
-			ui (obj): The ui to init widgets of.
-			widgets (str)(list): <QWidgets> if no arg is given, the operation will be performed on all widgets of the given ui name.
+		Parameters:
+			widgets (str)(list): The widget(s) to initialize.
 		'''
-		if widgets is None:
-			widgets = ui.widgets #get all widgets for the given ui.
-
 		for w in makeList(widgets): #if 'widgets' isn't a list, convert it to one.
-
-			if w not in ui.widgets:
-				ui.addWidgets(w)
-
-			#set styleSheet
-			if ui.level>2 or ui.isSubmenu and not w.prefix=='i': #if submenu and objectName doesn't start with 'i':
-				self.sb.setStyle(w, style='dark', backgroundOpacity=0)
-			else:
-				self.sb.setStyle(w, backgroundOpacity=0)
-
+			# print (1, 'initWidgets:', w.ui.name.ljust(26), w.prefix.ljust(25), (w.name or type(w).__name__).ljust(25), w.type.ljust(15), w.derivedType.ljust(15), id(w)) #debug
 			if w.derivedType in self.ef_widgetTypes:
-				# print (widgetName if widgetName else widget)
-				if ui.level<3 or w.type=='QMainWindow':
+				if w.ui.level<3:# or w.type=='QMainWindow':
 					w.installEventFilter(self.eventFilter)
 
 				if w.derivedType in ('QPushButton', 'QLabel'): #widget types to resize and center.
-					if ui.level<=2:
+					if w.ui.level<=2:
 						self.sb.resizeAndCenterWidget(w)
 
-				elif w.derivedType=='QWidget': #widget types to set an initial state as hidden.
-					if w.prefix=='w' and ui.level==1: #prefix returns True if widgetName startswith the given prefix, and is followed by three integers.
+				elif w.derivedType=='QWidget':
+					if w.prefix=='hidden_area': #widget types to set an initial state as hidden.
 						w.setVisible(False)
 
 
@@ -395,7 +353,7 @@ class Tcl(QtWidgets.QStackedWidget):
 
 		if w.type in ('ComboBox', 'ListWidget'):
 			try: #call the class method associated with the current widget.
-				w.method()
+				w.getSlot()()
 			except (AttributeError, TypeError) as error:
 				print (f'# Error: {__file__} in ef_showEvent\n#\t{error}.')
 				pass
@@ -414,7 +372,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''
 		'''
 		if w.type=='QWidget':
-			if w.prefix=='w':
+			if w.prefix=='hidden_area':
 				w.setVisible(True) #set visibility
 
 		elif w.derivedType=='QPushButton':
@@ -436,7 +394,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''
 		'''
 		if w.type=='QWidget':
-			if w.prefix=='w':
+			if w.prefix=='hidden_area':
 				w.setVisible(False) #set visibility
 
 		w.__class__.leaveEvent(w, event)
@@ -479,7 +437,7 @@ class Tcl(QtWidgets.QStackedWidget):
 
 				elif w.prefix=='v':
 					if w.ui.name=='cameras':
-						self.prevCamera(add=w.method)
+						self.prevCamera(add=w.getSlot())
 					#send click signal on mouseRelease.
 					w.click()
 
@@ -520,7 +478,7 @@ class Tcl(QtWidgets.QStackedWidget):
 			modifiers = self.app.keyboardModifiers()
 
 			if event.key()==self.key_show and not modifiers==QtCore.Qt.ControlModifier:
-				if w.name=='mainWindow':#w.type=='QMainWindow':
+				if w.type=='QMainWindow':
 					if w.ui.level>2:
 						self._key_show_release.emit()
 						w.releaseKeyboard()
@@ -568,13 +526,13 @@ class Tcl(QtWidgets.QStackedWidget):
 	_cameraHistory = []
 	def prevCamera(self, docString=False, method=False, allowCurrent=False, asList=False, add=None):
 		'''
-		:Parameters:
+		Parameters:
 			docString (bool): return the docString of last camera command. Default is off.
 			method (bool): return the method of last camera command. Default is off.
 			allowCurrent (bool): allow the current camera. Default is off.
 			add (str)(obj): Add a method, or name of method to be used as the command to the current camera.  (if this flag is given, all other flags are invalidated)
 
-		:Return:
+		Return:
 			if docString: 'string' description (derived from the last used camera command's docString) (asList: [string list] all docStrings, in order of use)
 			if method: method of last used camera command. (asList: [<method object> list} all methods, in order of use)
 			if asList: list of lists with <method object> as first element and <docString> as second. ie. [[<v001>, 'camera: persp']]
@@ -582,7 +540,7 @@ class Tcl(QtWidgets.QStackedWidget):
 		'''
 		if add: #set the given method as the current camera.
 			if not callable(add):
-				add = self.sb.getMethod('cameras', add)
+				add = self.sb.getSlot('cameras', add)
 			docString = add.__doc__
 			prevCameraList = self.prevCamera(allowCurrent=True, asList=1)
 			if not prevCameraList or not [add, docString]==prevCameraList[-1]: #ie. do not append perp cam if the prev cam was perp.
@@ -658,6 +616,23 @@ if __name__ == '__main__':
 # deprecated:
 # --------------------------------------------------------------------------------------------
 
+# self.app.focusChanged.connect(self.focusChanged)
+
+		# def focusChanged(self, old, new):
+		# 	'''Called on focus events.
+
+		# 	Parameters:
+		# 		old (obj): The widget with previous focus.
+		# 		new (obj): The widget with current focus.
+		# 	'''
+		# 	try:
+		# 		new.grabKeyboard()
+		# 	except AttributeError as error:
+		# 		self.setFocus()
+
+		# 	if not self.isActiveWindow():
+		# 		self.hide()
+
 # class Instance():
 # 	'''Manage multiple instances of the Tcl ui.
 # 	'''
@@ -698,7 +673,7 @@ if __name__ == '__main__':
 # 	def show(self, uiName=None, active=True):
 # 		'''Sets the widget as visible.
 
-# 		:Parameters:
+# 		Parameters:
 # 			uiName (str): Show the ui of the given name.
 # 			active (bool): Set as the active window.
 # 		'''
@@ -763,11 +738,11 @@ if __name__ == '__main__':
 	# def addUi(self, ui, query=False):
 	# 	'''Initializes the ui of the given name and it's dependancies.
 
-	# 	:Parameters:
+	# 	Parameters:
 	# 		ui (obj): The ui widget to be added to the layout stack.
 	# 		query (bool): Check whether the ui widget has been added.
 
-	# 	:Return:
+	# 	Return:
 	# 		(bool) When queried.
 	# 	'''
 	# 	if query:
