@@ -2,12 +2,12 @@
 # coding=utf-8
 from PySide2 import QtCore, QtGui, QtWidgets
 
-from attributes import Attributes
+from uitk.widgets.attributes import Attributes
 
 
 class Menu(QtWidgets.QMenu, Attributes):
 	'''
-	:Parameters:
+	Parameters:
 		menu_type (str): Menu style. valid parameters are: 'standard', 'context', 'form'
 		title (str): Text displayed at the menu's header.
 		padding (int): Area surrounding the menu.
@@ -45,51 +45,11 @@ class Menu(QtWidgets.QMenu, Attributes):
 
 		self.setAttributes(**kwargs)
 
+		self.childWidgets = set()
 		self.layouts = {} #a container for any created layouts.
-		self.uncheckAllButton = self._addUncheckAllButton()
+		self.toggleAllButton = self._addToggleAllButton()
 		self.applyButton = self._addApplyButton()
 
-		#assign properties
-		self.__class__.childWidgets = property(lambda self: self.getChildWidgets())
-
-
-	@property
-	def containsMenuItems(self):
-		'''Query whether any child objects have been added to the menu.
-		'''
-		state = True if self.childWidgets else False
-
-		return state
-
-
-	#property
-	def getChildWidgets(self, inc=[], exc=[]):
-		'''Get a list of the menu's child widgets.
-
-		:Parameters:
-			inc (list): Include only widgets of the given type(s). ie. ['QCheckBox', 'QRadioButton']
-			exc (list): Exclude widgets by type.
-
-		:Return:
-			(list) child widgets.
-		'''
-		if not hasattr(self, '_childWidgets'):
-			self._childWidgets = []
-
-		if any((inc, exc)):
-			try:
-				self._childWidgets = [
-					w for w in self._childWidgets 
-						if not w.__class__.__base__.__name__ in exc 
-							and (w.__class__.__base__.__name__ in inc if inc 
-								else w.__class__.__base__.__name__ not in inc)
-				]
-
-			except Exception as error:
-				print (__name__+':', 'getChildWidgets:', error)
-
-		return self._childWidgets
-
 
 	@property
 	def draggable_header(self):
@@ -99,7 +59,7 @@ class Menu(QtWidgets.QMenu, Attributes):
 			return self._draggable_header
 
 		except AttributeError as error:
-			from pushButtonDraggable import PushButtonDraggable
+			from uitk.widgets.pushButtonDraggable import PushButtonDraggable
 			dh = PushButtonDraggable()
 
 			wAction = QtWidgets.QWidgetAction(self)
@@ -110,11 +70,36 @@ class Menu(QtWidgets.QMenu, Attributes):
 			return self._draggable_header
 
 
+	@property
+	def containsMenuItems(self):
+		'''Query whether any child objects have been added to the menu.
+		'''
+		return bool(self.childWidgets)
+
+
+	def getChildWidgets(self, inc=[], exc=[]):
+		'''Get a list of the menu's child widgets.
+
+		:Parameters:
+			inc (list): Include only widgets of the given type(s). ie. ['QCheckBox', 'QRadioButton']
+			exc (list): Exclude widgets by type.
+		:Return:
+			(list) child widgets.
+		'''
+		if any((inc, exc)):
+			return [w for w in self.childWidgets 
+					if not w.__class__.__base__.__name__ in exc 
+						and (w.__class__.__base__.__name__ in inc if inc 
+					else w.__class__.__base__.__name__ not in inc)]
+		else:
+			return list(self.childWidgets)
+
+
 	def setTitle(self, title=''):
 		'''Set the menu's title to the given string.
 		If no title is given, the fuction will attempt to use the menu parents text.
 
-		:Parameters:
+		Parameters:
 			title (str): Text to apply to the menu's header.
 		'''
 		if not title:
@@ -127,13 +112,14 @@ class Menu(QtWidgets.QMenu, Attributes):
 					pass
 
 		self.draggable_header.setText(title)
+		super().setTitle(title)
 
 
 	def getActionAtIndex(self, index):
 		'''
 		'''
 		try:
-			return self.actions()[1:][index] #slice the actions list to omit the header and any built-in hidden buttons (ie. 'apply', 'uncheckAll').
+			return self.actions()[1:][index] #slice the actions list to omit the header and any built-in hidden buttons (ie. 'apply', 'toggleAll').
 
 		except IndexError as error:
 			return None
@@ -142,7 +128,7 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def insertAction_(self, wAction, index=-1):
 		'''Extends insertAction to allow inserting by index.
 
-		:Parameters:
+		Parameters:
 			wAction (obj): The widget action to insert.
 			index (int): The desired index. (It appends the action if index is invalid)
 		'''
@@ -153,11 +139,11 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def _addFormLayout(self, key='form', index=0):
 		'''Create a two column form layout that can later be referenced using a key.
 
-		:Parameters:
+		Parameters:
 			key (str)(int): The key identifier for the layout.
 			index(int): The index corresponding to the vertical positioning of the layout.
 
-		:Return:
+		Return:
 			(obj) QLayout.
 		'''
 		form = QtWidgets.QWidget(self)
@@ -177,10 +163,10 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def getFormLayout(self, key='form'):
 		'''Get a two column form layout using a key.
 
-		:Parameters:
+		Parameters:
 			key (str)(int): The key identifier for the layout.
 
-		:Return:
+		Return:
 			(obj) QLayout.
 		'''
 		try:
@@ -194,11 +180,11 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def _addVBoxLayout(self, key='vBox', index=0):
 		'''Create a single column vertical layout that can later be referenced using a key.
 
-		:Parameters:
+		Parameters:
 			key (str)(int): The key identifier for the layout.
 			index(int): The index corresponding to the vertical positioning of the layout.
 
-		:Return:
+		Return:
 			(obj) QLayout.
 		'''
 		form = QtWidgets.QWidget(self)
@@ -219,10 +205,10 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def getVBoxLayout(self, key='vBox'):
 		'''Get a vertical box layout using a key.
 
-		:Parameters:
+		Parameters:
 			key (str)(int): The key identifier for the layout.
 
-		:Return:
+		Return:
 			(obj) QLayout.
 		'''
 		try:
@@ -237,17 +223,17 @@ class Menu(QtWidgets.QMenu, Attributes):
 		'''Add a pushbutton that executes the parent object when pressed.
 		The button is hidden by default.
 
-		:Return:
+		Return:
 			(widget)
 		'''
 		if not self.parent():
-			# print ('# Error: {}: _addApplyButton(): operation requires a parent widget. #'.format(__file__))
+			# print (f'# Error: {__file__} in _addApplyButton\n#\tOperation requires a parent widget.')
 			return
 
 		w = QtWidgets.QPushButton('Apply') #self.add('QPushButton', setText='Apply', setObjectName=self.parent().objectName(), setToolTip='Execute the command.')
-		w.setObjectName(self.parent().objectName())
+		w.setObjectName('apply_button')
 		w.setToolTip('Execute the command.')
-		# w.released.connect(lambda: self.parent().released.emit()) #trigger the released signal on the parent when the apply button is released.
+		w.released.connect(lambda: self.parent().released.emit()) #trigger the released signal on the parent when the apply button is released.
 		w.setMinimumSize(119, 26)
 
 		layout = self.getVBoxLayout('menu_buttons') #get the 'menu_buttons' layout.
@@ -257,17 +243,18 @@ class Menu(QtWidgets.QMenu, Attributes):
 		return w
 
 
-	def _addUncheckAllButton(self):
+	def _addToggleAllButton(self):
 		'''Add a pushbutton that will uncheck any checkBoxes when pressed.
 		The button is hidden by default.
 
-		:Return:
+		Return:
 			(widget)
 		'''
 		w = QtWidgets.QPushButton('Uncheck All') #self.add('QPushButton', setText='Disable All', setObjectName='disableAll', setToolTip='Set all unchecked.')
-		w.setObjectName('uncheckAll')
-		w.setToolTip('Set all unchecked.')
-		w.released.connect(lambda: [c.setChecked(False) for c in self.getChildWidgets(inc=['QCheckBox'])]) #trigger the released signal on the parent when the apply button is released.
+		w.setObjectName('toggleAll')
+		w.setToolTip('Toggle all checked|unchecked.')
+
+		w.released.connect(lambda: [c.setChecked(not next(self.getChildWidgets(inc=['QCheckBox'])).checked()) for c in self.getChildWidgets(inc=['QCheckBox'])]) #trigger the released signal on the parent when the apply button is released.
 		w.setMinimumSize(119, 26)
 
 		layout = self.getVBoxLayout('menu_buttons') #get the 'menu_buttons' layout.
@@ -280,7 +267,7 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def add(self, widget, label='', checkableLabel=False, **kwargs):
 		'''Add items to the QMenu.
 
-		:Parameters:
+		Parameters:
 			widget (str)(obj): The widget to add. ie. 'QLabel', QtWidgets.QLabel, QtWidgets.QLabel()
 			lable (str): Add a label. (which is actually a checkbox. by default it is not checkable)
 			checkableLabel (bool): The label is checkable.
@@ -292,19 +279,18 @@ class Menu(QtWidgets.QMenu, Attributes):
 			setButtonSymbols_ (str): ie. 'PlusMinus'
 			setMinMax_ (str): Set the min, max, and step values with a string. ie. '1-100 step.1'
 
-		:Return:
- 			(obj) the added widget instance.
+		Return:
+			(obj) the added widget instance.
 
 		ex.call:
 		menu.add('QCheckBox', setText='Component Ring', setObjectName='chk000', setToolTip='Select component ring.')
 		'''
 		try: #get the widget
 			w = getattr(QtWidgets, widget)() #ie. QtWidgets.QAction(self) object from string.
+		except TypeError:
+			w = widget() #if callable(widget) ie. QtWidgets.QAction(self) object.
 		except:
-			try: #if callable(widget):
-				w = widget() #ie. QtWidgets.QAction(self) object.
-			except:
-				w = widget
+			w = widget
 
 		self.setAttributes(w, **kwargs) #set any additional given keyword args for the widget.
 
@@ -324,7 +310,7 @@ class Menu(QtWidgets.QMenu, Attributes):
 					l.setStyleSheet('QCheckBox::hover {background-color: rgb(100,100,100); color: white;}')
 				layout = self.getFormLayout() #get the default form layout.
 				layout.addRow(l, w)
-				self.childWidgets.append(l) #add the widget to the childWidgets list.
+				self.childWidgets.add(l) #add the widget to the childWidgets list.
 
 			else: #convert to action item, then add.
 				layout = self.getVBoxLayout() #get the default vertical box layout.
@@ -340,15 +326,14 @@ class Menu(QtWidgets.QMenu, Attributes):
 			except UnboundLocalError as error: #'l' does not exist. (not a form menu)
 				pass
 
-			self.childWidgets.append(w) #add the widget to the childWidgets list.
+			self.childWidgets.add(w) #add the widget to the childWidgets list.
 
 			setattr(self, w.objectName(), w) #add the widget's objectName as a QMenu attribute.
 
 			self._addToContextMenuToolTip(w)
 
-			#connect to '_setLastActiveChild' when signal activated.
-			if hasattr(w, 'released'):
-				w.released.connect(lambda w=w: self._setLastActiveChild(w))
+			if hasattr(w, 'released'): #Get the appropriate signal to connect to.
+				w.released.connect(lambda w=w: self._setLastActiveChild(w)) #Connect the signal if one was found.
 			elif hasattr(w, 'valueChanged'):
 				w.valueChanged.connect(lambda value, w=w: self._setLastActiveChild(value, w))
 
@@ -359,11 +344,11 @@ class Menu(QtWidgets.QMenu, Attributes):
 		'''Set the given widget as the last active.
 		Maintains a list of the last 10 active child widgets.
 
-		:Parameters:
+		Parameters:
 			widget = Widget to set as last active. The widget can later be returned by calling the 'lastActiveChild' method.
 			*args **kwargs = Any additional arguments passed in by the wiget's signal during a connect call.
 
-		:Return:
+		Return:
 			(obj) widget.
 		'''
 		# widget = args[-1]
@@ -382,10 +367,10 @@ class Menu(QtWidgets.QMenu, Attributes):
 		'''Get the given widget set as last active.
 		Contains a list of the last 10 active child widgets.
 
-		:Parameters:
+		Parameters:
 			name (bool): Return the last active widgets name as a string.
 
-		:Return:
+		Return:
 			(obj)(str)(list) dependant on flags.
 
 		ex. slot connection to the last active child widget:
@@ -412,7 +397,7 @@ class Menu(QtWidgets.QMenu, Attributes):
 	def _addToContextMenuToolTip(self, menuItem):
 		'''Add an item to the context menu toolTip.
 
-		:Parameters:
+		Parameters:
 			menuItem (obj): The item to add.
 		'''
 		p = self.parent()
@@ -432,19 +417,19 @@ class Menu(QtWidgets.QMenu, Attributes):
 
 	def leaveEvent(self, event):
 		'''
-		:Parameters:
+		Parameters:
 			event = <QEvent>
 		'''
 		self.hide()
 
-		QtWidgets.QMenu.leaveEvent(self, event)
+		super().leaveEvent(event)
 
 
 	def hide(self, force=False):
 		'''Sets the widget as invisible.
 		Prevents hide event under certain circumstances.
 
-		:Parameters:
+		Parameters:
 			force (bool): override preventHide.
 		'''
 		if force or not self.preventHide:
@@ -453,53 +438,51 @@ class Menu(QtWidgets.QMenu, Attributes):
 				try:
 					if w.view().isVisible(): #comboBox menu open.
 						return
-
 				except AttributeError as error:
 					pass
 
 			super().hide()
 
 
-	def show(self):
-		'''Show the menu.
+	def setVisible(self, state):
+		'''Called every time the widget is shown or hidden on screen.
 		'''
-		if self.containsMenuItems: #prevent show if the menu is empty.
+		if state: #visible
+			if not self.containsMenuItems: #prevent show if the menu is empty.
+				return
 
 			if not self.title():
 				self.setTitle()
 
-			if hasattr(self.parent(), 'released'):
+			if hasattr(self.parent(), 'released') and not self.parent().objectName()=='draggable_header':
+				# print (f'show menu | title: {self.title()} | {self.parent().objectName()} has attr released.') #debug
 				self.applyButton.show()
 
-			super().show()
+			checkboxes = self.getChildWidgets(inc=['QCheckBox'])
+			if checkboxes: #returns None if the menu doesn't contain checkboxes.
+				self.toggleAllButton.show()
 
+			self.resize(self.sizeHint().width(), self.sizeHint().height()+10) #self.setMinimumSize(width, self.sizeHint().height()+5)
+			getCenter = lambda w, p: QtCore.QPoint(p.x()-(w.width()/2), p.y()-(w.height()/4)) #get widget center position.
 
-	def showEvent(self, event):
-		'''
-		:Parameters:
-			event = <QEvent>
-		'''
-		self.resize(self.sizeHint().width(), self.sizeHint().height()+10) #self.setMinimumSize(width, self.sizeHint().height()+5)
-		getCenter = lambda w, p: QtCore.QPoint(p.x()-(w.width()/2), p.y()-(w.height()/4)) #get widget center position.
+			#set menu position
+			if self.position=='cursorPos':
+				pos = QtGui.QCursor.pos() #global position
+				self.move(getCenter(self, pos)) #move to cursor position.
 
-		#set menu position
-		if self.position=='cursorPos':
-			pos = QtGui.QCursor.pos() #global position
-			self.move(getCenter(self, pos)) #move to cursor position.
+			elif not isinstance(self.position, (type(None), str)): #if a widget is passed to 'position' (move to the widget's position).
+				pos = getattr(self.positionRelativeTo.rect(), self.position)
+				self.move(self.positionRelativeTo.mapToGlobal(pos()))
 
-		elif not isinstance(self.position, (type(None), str)): #if a widget is passed to 'position' (move to the widget's position).
-			pos = getattr(self.positionRelativeTo.rect(), self.position)
-			self.move(self.positionRelativeTo.mapToGlobal(pos()))
+			elif self.parent(): #if parent: map relative to parent.
+				pos = getattr(self.parent().rect(), self.position if not self.position=='cursorPos' else 'bottomLeft')
+				pos = self.parent().mapToGlobal(pos())
+				self.move(pos) # self.move(getCenter(self, pos))
 
-		elif self.parent(): #if parent: map relative to parent.
-			pos = getattr(self.parent().rect(), self.position if not self.position=='cursorPos' else 'bottomLeft')
-			pos = self.parent().mapToGlobal(pos())
-			self.move(pos) # self.move(getCenter(self, pos))
+		elif self.preventHide: #invisible
+			return
 
-			if self.getChildWidgets(inc=['QCheckBox']): #if the menu contains checkboxes:
-				self.uncheckAllButton.show()
-
-		QtWidgets.QMenu.showEvent(self, event)
+		super().setVisible(state)
 
 
 
@@ -529,6 +512,7 @@ class MenuInstance():
 			self._contextMenu = Menu(self, position='cursorPos', menu_type='context')
 			return self._contextMenu
 
+# -----------------------------------------------------------------------------
 
 
 
@@ -536,6 +520,10 @@ class MenuInstance():
 
 
 
+
+
+# -----------------------------------------------------------------------------
+
 if __name__ == "__main__":
 	import sys
 	app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(sys.argv) #return the existing QApplication object, or create a new one if none exists.
@@ -564,8 +552,6 @@ if __name__ == "__main__":
 	# m.exec_(parent=None)
 	sys.exit(app.exec_())
 
-
-
 # -----------------------------------------------------------------------------
 # Notes
 # -----------------------------------------------------------------------------
@@ -586,3 +572,65 @@ Promoting a widget in designer to use a custom class:
 
 # depricated:
 
+	# def hide(self, force=False):
+	# 	'''Sets the widget as invisible.
+	# 	Prevents hide event under certain circumstances.
+
+	# 	Parameters:
+	# 		force (bool): override preventHide.
+	# 	'''
+	# 	if force or not self.preventHide:
+
+	# 		for w in self.getChildWidgets():
+	# 			try:
+	# 				if w.view().isVisible(): #comboBox menu open.
+	# 					return
+	# 			except AttributeError as error:
+	# 				pass
+
+	# 		super().hide()
+
+
+	# def show(self):
+	# 	'''Show the menu.
+	# 	'''
+	# 	if not self.containsMenuItems: #prevent show if the menu is empty.
+	# 		return
+
+	# 	if not self.title():
+	# 			self.setTitle()
+
+	# 	if hasattr(self.parent(), 'released') and not self.parent().objectName()=='draggable_header':
+	# 		# print (f'show menu | title: {self.title()} | {self.parent().objectName()} has attr released.') #debug
+	# 		self.applyButton.show()
+
+	# 	checkboxes = self.getChildWidgets(inc=['QCheckBox'])
+	# 	if checkboxes: #returns None if the menu doesn't contain checkboxes.
+	# 		self.toggleAllButton.show()
+
+	# 	super().show()
+
+
+	# def showEvent(self, event):
+	# 	'''
+	# 	Parameters:
+	# 		event = <QEvent>
+	# 	'''
+	# 	self.resize(self.sizeHint().width(), self.sizeHint().height()+10) #self.setMinimumSize(width, self.sizeHint().height()+5)
+	# 	getCenter = lambda w, p: QtCore.QPoint(p.x()-(w.width()/2), p.y()-(w.height()/4)) #get widget center position.
+
+	# 	#set menu position
+	# 	if self.position=='cursorPos':
+	# 		pos = QtGui.QCursor.pos() #global position
+	# 		self.move(getCenter(self, pos)) #move to cursor position.
+
+	# 	elif not isinstance(self.position, (type(None), str)): #if a widget is passed to 'position' (move to the widget's position).
+	# 		pos = getattr(self.positionRelativeTo.rect(), self.position)
+	# 		self.move(self.positionRelativeTo.mapToGlobal(pos()))
+
+	# 	elif self.parent(): #if parent: map relative to parent.
+	# 		pos = getattr(self.parent().rect(), self.position if not self.position=='cursorPos' else 'bottomLeft')
+	# 		pos = self.parent().mapToGlobal(pos())
+	# 		self.move(pos) # self.move(getCenter(self, pos))
+
+	# 	QtWidgets.QMenu.showEvent(self, event)
\ No newline at end of file
